package com.ibm.bpac.wjde;

/*
 * Sample source code is furnished by IBM as simple examples to provide an
 * illustration. These examples have not been thoroughly tested under all
 * conditions.  IBM, therefore, cannot guarantee reliability, serviceability
 * or function of these programs.
 * All programs contained herein are provided to you "AS IS".
 *
 *
 * Licensed Materials - Property of IBM
 *
 * 5648-D75
 *
 * (C) Copyright IBM Corp. 1999, 2000 All Rights Reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp
 */

/**
 * Module Name: JDE_ItemMasterExport.java
 * @author KDS
 * @version 1.0
 *
 * history
 * -----------  ---  --------------  --------------------------------------
 * 08/02/2001   KDS                     - Creation
*/

import java.io.*;
import java.util.*;

import com.ibm.as400.access.*;
import com.ibm.mq.*;


/**
 * JDE_ItemMasterExport class will receive data from an AS400 DataQueue and call a C Source
 * Adapter to handle mappings and put the msg to a Queue
 */
public class JDE_ItemMasterExport extends Thread
{
    public static final String copyrightNotice = "(C) Copyright IBM Corp. 2001";

    // below for obtaining the application id dynamically.
    private static final String CLASS_NAME = "JDE_ItemMasterExport";

    private Properties config = null;

    /**
     * construct an JDE_ItemMasterExport object based on a properties file
     * @param fileName the file containing the properties/parameters
     */
    public JDE_ItemMasterExport(String fileName)
    {
System.out.println("in constructor");
        try
        {
            config = new Properties();
System.out.println("calling new FileInputStream for "+fileName);
            config.load(new FileInputStream(fileName));
        }
        catch(Exception e)
        {
            e.printStackTrace();
            System.exit(-1);
        }
    }

    /**
     * construct an JDE_ItemMasterExport object based on properties
     * @param p the properties/parameters
     */
    public JDE_ItemMasterExport(Properties p)
    {
        config = p;
    }

    /**
     * the thread starts running here
     */
    public void run()
    {
System.out.println("entering run()");
        JDE_ItemMasterExport();
    }


    /**
     * receive from AS400 DataQueue and call Source Adapter
     */
    private void JDE_ItemMasterExport()
    {
	  String dtqName = config.getProperty("DataQueueName");
        if(dtqName == null)
        {
            System.out.println("No Data Queue Name is specified");
            return;
        }

        try
        {
            // Gets AS400 host
            AS400 as400 = new AS400();
		JDE_ItemSASimple adapter = new JDE_ItemSASimple();
  		
            DataQueue dtq = new DataQueue(as400, dtqName);

            boolean read4Ever = true;
            while(read4Ever)
            {
                DataQueueEntry entry = dtq.read(-1);
                String strData = entry.getString();
                adapter.executeJDE_ItemSF(strData);
            }
        }
        catch(Exception e)
        {
            e.printStackTrace();
        }
	  catch(Throwable e)
        {
            e.printStackTrace();
        }

    }

    /**
     * the main entry point
     * @param args command line parameters
     */
    public static void main(String args[])
    {
        System.out.println("***********************************");
        System.out.println("Start of execute for JDE_ItemMasterExport");
        System.out.println("***********************************");
        if(args.length == 0)
        {
            System.out.println("Usage: java JDE_ItemMasterExport fileName");
            return;
        }

        try
        {
            new JDE_ItemMasterExport(args[0]).start();
        }
        catch (Exception e)
        {
            e.printStackTrace();    // Prints the full trace of the exception.  For debug only.
        }
    }
}
